@@ -520,11 +520,10 @@ class NgramsModule(PreprocessorModule):
     ngrams_range = settings.Setting((1, 2))
 
     def setup_method_layout(self):
-        self.method_layout.addWidget(
-            widgets.RangeWidget(None, self, 'ngrams_range', minimum=1, maximum=10, step=1,
-                                min_label='Range:', dtype=int,
-                                callback=self.update_value)
-        )
+        w = widgets.RangeWidget(None, self, 'ngrams_range', minimum=1, maximum=10, step=1,
+                                min_label='Range:', dtype=int)
+        w.editingFinished.connect(self.update_value)
+        self.method_layout.addWidget(w)
 
     def get_value(self):
         return self.ngrams_range
@@ -546,7 +545,7 @@ class POSTaggingModule(SingleMethodModule):
         super().setup_method_layout()
         # initialize all methods except StanfordPOSTagger
         # cannot be done in superclass due to StanfordPOSTagger
-        self.methods = [method() for method in self.methods[:self.STANFORD]]
+        self.methods = [method() for method in self.methods[:self.STANFORD]] + [self.methods[self.STANFORD]]
 
         self.stanford = ResourceLoader(widget=self.master, model_format='Stanford model (*.model *.tagger)',
                                        provider_format='Java file (*.jar)',
@@ -567,7 +566,14 @@ class POSTaggingModule(SingleMethodModule):
                 self.update_value()
             except ValueError as e:
                 if not silent:
-                    self.master.Error.stanford(str(e))
+                    self.master.Error.stanford_tagger(str(e))
+
+        # if stanford fails to load data, change saved index to default
+        if self.method_index == self.STANFORD and not valid:
+            self.method_index = 0
+            self.group.button(self.method_index).setChecked(True)
+            self.group.button(self.method_index).setEnabled(True)
+            self.master.Error.stanford_tagger("Changing to Averaged Perceptron Tagger")
 
         self.group.button(self.STANFORD).setChecked(valid)
         self.group.button(self.STANFORD).setEnabled(valid)
@@ -613,7 +619,7 @@ class OWPreprocess(OWWidget):
     ngrams_range = settings.SettingProvider(NgramsModule)
     pos_tagger = settings.SettingProvider(POSTaggingModule)
 
-    control_area_width = 250
+    control_area_width = 180
     buttons_area_orientation = Qt.Vertical
 
     UserAdviceMessages = [
@@ -675,6 +681,7 @@ class OWPreprocess(OWWidget):
         self.scroll.resize(frame_layout.sizeHint())
         self.scroll.setMinimumHeight(500)
         self.set_minimal_width()
+        self.mainArea.layout().sizeHint()
         self.mainArea.layout().addWidget(self.scroll)
 
         # Buttons area
@@ -682,7 +689,7 @@ class OWPreprocess(OWWidget):
 
         commit_button = gui.auto_commit(self.buttonsArea, self, 'autocommit',
                                         'Commit', box=False)
-        commit_button.setFixedWidth(self.control_area_width - 5)
+        commit_button.setFixedWidth(self.control_area_width)
 
         self.buttonsArea.layout().addWidget(commit_button)
 
