@@ -351,11 +351,7 @@ class FileWidget(QWidget):
                 self.recent_files.remove(file)
 
     def open_file(self, path):
-        try:
-            self.on_open.emit(path if path != self.empty_file_label else '')
-        except (OSError, IOError):
-            self.loading_error_signal.emit('Could not open "{}".'
-                                           .format(path))
+        self.on_open.emit(path if path != self.empty_file_label else '')
 
     def get_selected_filename(self):
         if self.recent_files:
@@ -535,6 +531,7 @@ class ResourceLoader(QWidget, OWComponent):
     valueChanged = pyqtSignal(str, str)
 
     recent_files = settings.Setting([])
+    recent_provider = settings.Setting([])
     resource_path = settings.Setting('')
 
     def __init__(self, widget, model_format, provider_format,
@@ -543,7 +540,7 @@ class ResourceLoader(QWidget, OWComponent):
         OWComponent.__init__(self, widget)
 
         self.model_path = None
-        layout = QHBoxLayout(self, spacing=0)
+        layout = QHBoxLayout(self)
         layout.setContentsMargins(0, 0, 0, 0)
 
         self.model_widget = FileWidget(recent_files=self.recent_files, dialog_title='Load model',
@@ -554,7 +551,7 @@ class ResourceLoader(QWidget, OWComponent):
 
         layout.addWidget(self.model_widget)
 
-        self.provider_widget = FileWidget(recent_files=None, dialog_title='Load provider',
+        self.provider_widget = FileWidget(recent_files=self.recent_provider, dialog_title='Load provider',
                                           dialog_format=provider_format, start_dir=None,
                                           on_open=self.load_provider, allow_empty=False,
                                           reload_button=False, browse_label=provider_button_label)
